@@ -24,13 +24,11 @@ static void store_input_parameters (
     ESYS_CONTEXT *esysContext,
     const TPM2B_AUTH *auth)
 {
-    if (auth == NULL) {
-        esysContext->in.HMAC_Start.auth = NULL;
-    } else {
+    if (auth == NULL)
+        memset(&esysContext->in.HMAC_Start.authData, 0,
+                sizeof(esysContext->in.HMAC_Start.authData));
+    else
         esysContext->in.HMAC_Start.authData = *auth;
-        esysContext->in.HMAC_Start.auth =
-            &esysContext->in.HMAC_Start.authData;
-    }
 }
 
 /** One-Call function for TPM2_HMAC_Start
@@ -104,10 +102,10 @@ Esys_HMAC_Start(
         r = Esys_HMAC_Start_Finish(esysContext, sequenceHandle);
         /* This is just debug information about the reattempt to finish the
            command */
-        if ((r & ~TSS2_RC_LAYER_MASK) == TSS2_BASE_RC_TRY_AGAIN)
+        if (base_rc(r) == TSS2_BASE_RC_TRY_AGAIN)
             LOG_DEBUG("A layer below returned TRY_AGAIN: %" PRIx32
                       " => resubmitting command", r);
-    } while ((r & ~TSS2_RC_LAYER_MASK) == TSS2_BASE_RC_TRY_AGAIN);
+    } while (base_rc(r) == TSS2_BASE_RC_TRY_AGAIN);
 
     /* Restore the timeout value to the original value */
     esysContext->timeout = timeouttmp;
@@ -194,8 +192,12 @@ Esys_HMAC_Start_Async(
     /* Calculate the cpHash Values */
     r = init_session_tab(esysContext, shandle1, shandle2, shandle3);
     return_state_if_error(r, _ESYS_STATE_INIT, "Initialize session resources");
-    iesys_compute_session_value(esysContext->session_tab[0],
+    if (handleNode != NULL)
+        iesys_compute_session_value(esysContext->session_tab[0],
                 &handleNode->rsrc.name, &handleNode->auth);
+    else
+        iesys_compute_session_value(esysContext->session_tab[0], NULL, NULL);
+
     iesys_compute_session_value(esysContext->session_tab[1], NULL, NULL);
     iesys_compute_session_value(esysContext->session_tab[2], NULL, NULL);
 
@@ -283,7 +285,7 @@ Esys_HMAC_Start_Finish(
 
     /*Receive the TPM response and handle resubmissions if necessary. */
     r = Tss2_Sys_ExecuteFinish(esysContext->sys, esysContext->timeout);
-    if ((r & ~TSS2_RC_LAYER_MASK) == TSS2_BASE_RC_TRY_AGAIN) {
+    if (base_rc(r) == TSS2_BASE_RC_TRY_AGAIN) {
         LOG_DEBUG("A layer below returned TRY_AGAIN: %" PRIx32, r);
         esysContext->state = _ESYS_STATE_SENT;
         goto error_cleanup;
@@ -342,11 +344,9 @@ Esys_HMAC_Start_Finish(
 
     /*  The name of a sequence object is an empty buffer */
     sequenceHandleNode->rsrc.name.size = 0;
-    /* Store the auth value parameter in the object meta data if passed */
-    if (esysContext->in.HMAC_Start.auth == NULL)
-        sequenceHandleNode->auth.size = 0;
-    else
-        sequenceHandleNode->auth = *esysContext->in.HMAC_Start.auth;
+
+    /* Store the auth value parameter in the object meta data */
+    sequenceHandleNode->auth = esysContext->in.HMAC_Start.authData;
     esysContext->state = _ESYS_STATE_INIT;
 
     return TSS2_RC_SUCCESS;
