@@ -1,9 +1,13 @@
-/* SPDX-License-Identifier: BSD-2 */
+/* SPDX-License-Identifier: BSD-2-Clause */
 /*******************************************************************************
  * Copyright 2017-2018, Fraunhofer SIT sponsored by Infineon Technologies AG
  * All rights reserved.
  *******************************************************************************/
 
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+
 #include <inttypes.h>
 #include <string.h>
 
@@ -13,6 +17,7 @@
 #include "esys_iutil.h"
 #define LOGMODULE esys
 #include "util/log.h"
+#include "util/aux_util.h"
 
 /** Marshal an array of BYTE structures into a byte buffer.
  *
@@ -96,33 +101,6 @@ iesys_MU_BYTE_array_Unmarshal(
     return TSS2_RC_SUCCESS;
 }
 
-
-/** Check, if a variable has a possible value of type IESYSC_RESOURCE_TYPE_CONSTANT.
- *
- * @param[in] in variable to check.
- * @retval TSS2_RC_SUCCESS on success.
- */
-TSS2_RC
-Tss2_MU_IESYSC_RESOURCE_TYPE_CONSTANT_check(
-    const IESYSC_RESOURCE_TYPE_CONSTANT *in)
-{
-    LOG_TRACE("called: in=%p", in);
-    if (in == NULL) {
-        LOG_ERROR("in==NULL");
-        return TSS2_SYS_RC_BAD_REFERENCE;
-    }
-    /* No Error-Messages, since this function may fail for a good reasons. */
-    if (FALSE
-        || (*in == IESYSC_KEY_RSRC)
-        || (*in == IESYSC_NV_RSRC)
-        || (*in == IESYSC_SESSION_RSRC)
-        || (*in == IESYSC_WITHOUT_MISC_RSRC)) {
-        return TSS2_RC_SUCCESS;
-    } else {
-        return TSS2_SYS_RC_BAD_VALUE;
-    }
-    return TSS2_RC_SUCCESS;
-}
 /** Marshal a constant of type IESYSC_PARAM_ENCRYPT into a byte buffer.
  *
  * @param[in] src constant to be marshaled.
@@ -201,10 +179,9 @@ iesys_MU_IESYSC_PARAM_ENCRYPT_check(
         || (*in == ENCRYPT)
         || (*in == NO_ENCRYPT)) {
         return TSS2_RC_SUCCESS;
-    } else {
-        return TSS2_SYS_RC_BAD_VALUE;
     }
-    return TSS2_RC_SUCCESS;
+
+    return TSS2_SYS_RC_BAD_VALUE;
 }
 /** Marshal a constant of type IESYSC_PARAM_DECRYPT into a byte buffer.
  *
@@ -284,10 +261,9 @@ iesys_MU_IESYSC_PARAM_DECRYPT_check(
         || (*in == DECRYPT)
         || (*in == NO_DECRYPT)) {
         return TSS2_RC_SUCCESS;
-    } else {
-        return TSS2_SYS_RC_BAD_VALUE;
     }
-    return TSS2_RC_SUCCESS;
+
+    return TSS2_SYS_RC_BAD_VALUE;
 }
 /** Marshal a constant of type IESYSC_TYPE_POLICY_AUTH into a byte buffer.
  *
@@ -368,10 +344,9 @@ iesys_MU_IESYSC_TYPE_POLICY_AUTH_check(
         || (*in == POLICY_AUTH)
         || (*in == NO_POLICY_AUTH)) {
         return TSS2_RC_SUCCESS;
-    } else {
-        return TSS2_SYS_RC_BAD_VALUE;
     }
-    return TSS2_RC_SUCCESS;
+
+    return TSS2_SYS_RC_BAD_VALUE;
 }
 
 /** Marshal a IESYS_SESSION structure into a byte buffer.
@@ -634,10 +609,9 @@ iesys_MU_IESYSC_RESOURCE_TYPE_check(
             || (*in == IESYSC_SESSION_RSRC)
             || (*in == IESYSC_WITHOUT_MISC_RSRC)) {
         return TSS2_RC_SUCCESS;
-    } else {
-        return TSS2_SYS_RC_BAD_VALUE;
     }
-    return TSS2_RC_SUCCESS;
+
+    return TSS2_SYS_RC_BAD_VALUE;
 }
 
 /** Marshal a IESYS_RSRC_UNION union into a byte buffer.
