@@ -188,7 +188,7 @@ Fapi_ChangeAuth_Async(
     /* Get a session for further authorizing and integrity checking the
        subsequent ChangeAuth calls. */
     r = ifapi_get_sessions_async(context,
-                                 IFAPI_SESSION_GENEK | IFAPI_SESSION1,
+                                 IFAPI_SESSION_GEN_SRK | IFAPI_SESSION1,
                                  TPMA_SESSION_DECRYPT, 0);
     goto_if_error_reset_state(r, "Create sessions", error_cleanup);
 
