@@ -374,6 +374,9 @@ Fapi_Delete_Async(
     check_not_null(context);
     check_not_null(path);
 
+    /* Cleanup command context. */
+    memset(&context->cmd, 0, sizeof(IFAPI_CMD_STATE));
+
     /* Helpful alias pointers */
     IFAPI_Entity_Delete * command = &(context->cmd.Entity_Delete);
     IFAPI_OBJECT *object = &command->object;
@@ -443,7 +446,7 @@ Fapi_Delete_Async(
         goto_if_error(r, "Initialize Entity_Delete", error_cleanup);
 
         r = ifapi_get_sessions_async(context,
-                                 IFAPI_SESSION_GENEK | IFAPI_SESSION1,
+                                 IFAPI_SESSION_GEN_SRK | IFAPI_SESSION1,
                                  0, 0);
         goto_if_error_reset_state(r, "Create sessions", error_cleanup);
 
