@@ -148,6 +148,9 @@ Fapi_GetRandom_Async(
     /* Check for NULL parameters */
     check_not_null(context);
 
+    /* Cleanup command context. */
+    memset(&context->cmd, 0, sizeof(IFAPI_CMD_STATE));
+
     /* Helpful alias pointers */
     IFAPI_GetRandom * command = &context->get_random;
 
@@ -162,7 +165,7 @@ Fapi_GetRandom_Async(
 
     /* Start a session for integrity protection and encryption of random data. */
     r = ifapi_get_sessions_async(context,
-                                 IFAPI_SESSION_GENEK | IFAPI_SESSION1,
+                                 IFAPI_SESSION_GEN_SRK | IFAPI_SESSION1,
                                  TPMA_SESSION_ENCRYPT | TPMA_SESSION_DECRYPT, 0);
     return_if_error_reset_state(r, "Create FAPI session");
 
