@@ -22,7 +22,7 @@
 #include "fapi_crypto.h"
 #include "fapi_policy.h"
 #include "ifapi_curl.h"
-#include "ifapi_get_intl_cert.h"
+#include "ifapi_get_web_cert.h"
 #include "ifapi_helpers.h"
 #include "tss2_mu.h"
 
@@ -37,6 +37,9 @@
 #define ECC_EK_TEMPLATE_NV_INDEX 0x01c0000c
 #define ECC_SM2_EK_TEMPLATE_NV_INDEX 0x01c0001b
 
+#define FAPI_TEST_ROOT_CERT_FILE "./ca/root-ca/root-ca.cert.pem"
+#define FAPI_TEST_INT_CERT_FILE "./ca/intermed-ca/intermed-ca.cert.pem"
+
 /** Error cleanup of provisioning
  *
  * The profile directory will be deleted.
@@ -452,7 +455,6 @@ Fapi_Provision_Finish(FAPI_CONTEXT *context)
                 context->state = PROVISION_PREPARE_GET_CAP_AUTH_STATE;
                 return TSS2_FAPI_RC_TRY_AGAIN;
             }
-            fallthrough;
 
         statecase(context->state, PROVISION_INIT);
 
@@ -891,6 +893,16 @@ Fapi_Provision_Finish(FAPI_CONTEXT *context)
 #ifdef SELF_GENERATED_CERTIFICATE
 #pragma message ( "*** Allow self generated certifcate ***" )
             root_ca_file = getenv("FAPI_TEST_ROOT_CERT");
+
+            if (root_ca_file && strcasecmp(root_ca_file, "self") == 0) {
+                /* The self signed root cert will be used as intermediate certificate. */
+                context->state = PROVISION_PREPARE_READ_INT_CERT;
+                return TSS2_FAPI_RC_TRY_AGAIN;
+            }
+
+            if (!root_ca_file && ifapi_io_path_exists(FAPI_TEST_ROOT_CERT_FILE)) {
+                root_ca_file = FAPI_TEST_ROOT_CERT_FILE;
+            }
 #endif
             if (!root_ca_file) {
                 context->state = PROVISION_EK_CHECK_CERT;
@@ -917,6 +929,9 @@ Fapi_Provision_Finish(FAPI_CONTEXT *context)
 #ifdef SELF_GENERATED_CERTIFICATE
 #pragma message ( "*** Allow self generated certifcate ***" )
             int_ca_file = getenv("FAPI_TEST_INT_CERT");
+            if (!int_ca_file && ifapi_io_path_exists(FAPI_TEST_INT_CERT_FILE)) {
+                int_ca_file = FAPI_TEST_INT_CERT_FILE;
+            }
 #endif
             if (!int_ca_file) {
                 context->state = PROVISION_EK_CHECK_CERT;
@@ -1571,13 +1586,15 @@ Fapi_Provision_Finish(FAPI_CONTEXT *context)
             return_try_again(r);
             goto_if_error_reset_state(r, "GetCapablity_Finish", error_cleanup);
 
-            if ((*capabilityData)->data.tpmProperties.tpmProperty[0].value == VENDOR_INTC) {
+            if ((*capabilityData)->data.tpmProperties.tpmProperty[0].value == VENDOR_INTC ||
+                (*capabilityData)->data.tpmProperties.tpmProperty[0].value == VENDOR_AMD) {
                 /* Get INTEL certificate for EK public hash via web */
                 uint8_t *cert_buffer = NULL;
                 size_t cert_size;
                 TPM2B_PUBLIC public;
-                r = ifapi_get_intl_ek_certificate(context, &pkey->public, &cert_buffer,
-                                                  &cert_size);
+                r = ifapi_get_web_ek_certificate(context, &pkey->public,
+                                (*capabilityData)->data.tpmProperties.tpmProperty[0].value,
+                                &cert_buffer, &cert_size);
                 goto_if_error_reset_state(r, "Get certificates", error_cleanup);
 
                 r = ifapi_cert_to_pem(cert_buffer, cert_size, &command->pem_cert,
@@ -1585,6 +1602,11 @@ Fapi_Provision_Finish(FAPI_CONTEXT *context)
                 SAFE_FREE(cert_buffer);
                 goto_if_error_reset_state(r, "Convert certificate buffer to PEM.",
                                           error_cleanup);
+
+                 r = ifapi_curl_verify_ek_cert(NULL, NULL, command->pem_cert);
+                 goto_if_error_reset_state(r, "Verify EK certificate.",
+                                           error_cleanup);
+
             } else {
                 /* No certificate was stored in the TPM and ek_cert_less was not set.*/
                 goto_error(r, TSS2_FAPI_RC_NO_CERT,
