@@ -55,7 +55,7 @@ typedef UINT32 TSS2_KEY_TYPE;
 #define MAX_PLATFORM_CERT_HANDLE 0x01C0FFFF
 
 typedef UINT8 IFAPI_SESSION_TYPE;
-#define IFAPI_SESSION_GENEK   0x01
+#define IFAPI_SESSION_GEN_SRK 0x01
 #define IFAPI_SESSION1        0x02
 #define IFAPI_SESSION2        0x04
 #define IFAPI_SESSION_USE_SRK 0x08
@@ -69,7 +69,9 @@ typedef UINT8 IFAPI_SESSION_TYPE;
 #define IFAPI_PUB_KEY_DIR "ext"
 #define IFAPI_POLICY_DIR "policy"
 #define IFAPI_PEM_PUBLIC_STRING "-----BEGIN PUBLIC KEY-----"
-#define IFAPI_PEM_PRIVATE_KEY "-----PRIVATE KEY-----"
+#define IFAPI_PEM_PRIVATE_KEY "-----BEGIN PRIVATE KEY-----"
+#define IFAPI_PEM_RSA_PRIVATE_KEY "-----BEGIN RSA PRIVATE KEY-----"
+#define IFAPI_PEM_ECC_PRIVATE_KEY "-----BEGIN EC PRIVATE KEY-----"
 #define IFAPI_JSON_TAG_POLICY "policy"
 #define IFAPI_JSON_TAG_OBJECT_TYPE "objectType"
 #define IFAPI_JSON_TAG_DUPLICATE "public_parent"
@@ -712,6 +714,9 @@ typedef struct {
     TPM2B_PRIVATE *private;
     char *jso_string;
     const IFAPI_PROFILE *profile;
+    IFAPI_KEY_TEMPLATE public_templ;  /**< The template for the keys public data */
+    const char *ossl_priv;            /**< Private OSSL PEM key to be import. */
+    TPM2B_SENSITIVE sensitive;        /**< The sensitive part of an OSSL key. */
 } IFAPI_ImportKey;
 
 
@@ -1026,6 +1031,7 @@ enum _FAPI_STATE {
     DATA_ENCRYPT_WAIT_FOR_PROFILE,
     DATA_ENCRYPT_WAIT_FOR_SESSION,
     DATA_ENCRYPT_WAIT_FOR_KEY,
+    DATA_ENCRYPT_WAIT_FOR_EXT_KEY,
     DATA_ENCRYPT_WAIT_FOR_FLUSH,
     DATA_ENCRYPT_WAIT_FOR_RSA_ENCRYPTION,
     DATA_ENCRYPT_CLEAN,
@@ -1207,5 +1213,6 @@ struct FAPI_CONTEXT {
 #define VENDOR_IFX  0x49465800
 #define VENDOR_INTC 0x494E5443
 #define VEDNOR_IBM  0x49424D20
+#define VENDOR_AMD  0x414D4400
 
 #endif /* FAPI_INT_H */
