@@ -17,6 +17,15 @@
 #include "tss2_fapi.h"
 #include "fapi_int.h"
 
+/** Type for representing a external public key
+ */
+typedef struct {
+    TPMI_ALG_HASH bank;
+    TPM2_HANDLE pcr;
+    TPM2B_DIGEST value;
+} IFAPI_PCR_REG;
+
+
 TSS2_RC
 ifapi_create_dirs(const char *supdir, const char *path);
 
@@ -130,6 +139,7 @@ TSS2_RC
 ifapi_compute_quote_info(
     IFAPI_OBJECT *sig_key_object,
     TPM2B_ATTEST *tpm_quoted,
+    FAPI_QUOTE_INFO *fapi_quote_info,
     char **quoteInfo);
 
 TSS2_RC
@@ -164,10 +174,17 @@ ifapi_filter_pcr_selection_by_index(
     const TPM2_HANDLE *pcr_index,
     size_t pcr_count);
 
+TSS2_RC
+ifapi_calculate_pcrs(
+    json_object *jso_event_list,
+    const TPML_PCR_SELECTION *pcr_selection,
+    TPMI_ALG_HASH pcr_digest_hash_alg,
+    const TPM2B_DIGEST *quote_digest,
+    IFAPI_PCR_REG *pcrs);
+
 TSS2_RC ifapi_calculate_pcr_digest(
     json_object *jso_event_list,
-    const FAPI_QUOTE_INFO *quote_info,
-    TPM2B_DIGEST *pcr_digest);
+    const FAPI_QUOTE_INFO *quote_info);
 
 TSS2_RC
 ifapi_compute_policy_digest(
