@@ -63,8 +63,10 @@
  *         or contains illegal characters.
  */
 TSS2_RC
-ifapi_calculate_tree(
-    FAPI_CONTEXT *context,
+ifapi_calculate_tree_ex(
+    IFAPI_POLICY_CTX *context,
+    IFAPI_POLICY_STORE *pstore,
+    IFAPI_IO *io,
     const char *policyPath,
     TPMS_POLICY *policy,
     TPMI_ALG_HASH hash_alg,
@@ -74,49 +76,36 @@ ifapi_calculate_tree(
     size_t i;
     TSS2_RC r = TSS2_RC_SUCCESS;
     bool already_computed = false;
-    IFAPI_POLICY_EVAL_INST_CTX *eval_ctx = NULL;
-    ifapi_policyeval_INST_CB *callbacks;
 
-    if (context->policy.state == POLICY_INIT && !policyPath)
+    if (context->state == POLICY_INIT && !policyPath)
         /* Skip policy reading */
-        context->policy.state = POLICY_INSTANTIATE_PREPARE;
+        context->state = POLICY_INSTANTIATE_PREPARE;
 
-    switch (context->policy.state) {
-    statecase(context->policy.state, POLICY_INIT);
+    switch (context->state) {
+    statecase(context->state, POLICY_INIT);
         fallthrough;
 
-    statecase(context->policy.state, POLICY_READ);
-        r = ifapi_policy_store_load_async(&context->pstore, &context->io, policyPath);
+    statecase(context->state, POLICY_READ);
+        r = ifapi_policy_store_load_async(pstore, io, policyPath);
         goto_if_error2(r, "Can't open: %s", cleanup, policyPath);
         fallthrough;
 
-    statecase(context->policy.state, POLICY_READ_FINISH);
-        r = ifapi_policy_store_load_finish(&context->pstore, &context->io, policy);
+    statecase(context->state, POLICY_READ_FINISH);
+        r = ifapi_policy_store_load_finish(pstore, io, policy);
         return_try_again(r);
-        return_if_error_reset_state(r, "read_finish failed");
+        goto_if_error(r, "read_finish failed", cleanup);
         fallthrough;
 
-    statecase(context->policy.state, POLICY_INSTANTIATE_PREPARE);
-        eval_ctx = &context->policy.eval_ctx;
-        callbacks = &eval_ctx->callbacks;
-        callbacks->cbname = ifapi_get_object_name;
-        callbacks->cbname_userdata = context;
-        callbacks->cbpublic = ifapi_get_key_public;
-        callbacks->cbpublic_userdata = context;
-        callbacks->cbnvpublic = ifapi_get_nv_public;
-        callbacks->cbnvpublic_userdata = context;
-        callbacks->cbpcr = ifapi_read_pcr;
-        callbacks->cbpcr_userdata = context;
-
-        r = ifapi_policyeval_instantiate_async(eval_ctx, policy, callbacks);
+    statecase(context->state, POLICY_INSTANTIATE_PREPARE);
+        r = ifapi_policyeval_instantiate_async(&context->eval_ctx, policy);
         goto_if_error(r, "Instantiate policy.", cleanup);
         fallthrough;
 
-    statecase(context->policy.state, POLICY_INSTANTIATE);
-        r = ifapi_policyeval_instantiate_finish(&context->policy.eval_ctx);
+    statecase(context->state, POLICY_INSTANTIATE);
+        r = ifapi_policyeval_instantiate_finish(&context->eval_ctx);
         FAPI_SYNC(r, "Instantiate policy.", cleanup);
-        ifapi_free_node_list(context->policy.eval_ctx.policy_elements);
-        context->policy.eval_ctx.policy_elements = NULL;
+        ifapi_free_node_list(context->eval_ctx.policy_elements);
+        context->eval_ctx.policy_elements = NULL;
 
         if (!(*hash_size = ifapi_hash_get_digest_size(hash_alg))) {
             goto_error(r, TSS2_FAPI_RC_BAD_VALUE,
@@ -134,8 +123,8 @@ ifapi_calculate_tree(
         if (already_computed)
             break;
 
-        if (i > TPM2_NUM_PCR_BANKS) {
-            return_error(TSS2_FAPI_RC_BAD_VALUE, "Table overflow");
+        if (i >= TPM2_NUM_PCR_BANKS) {
+            goto_if_error(TSS2_FAPI_RC_BAD_VALUE, "Table overflow", cleanup);
         }
         *digest_idx = i;
         policy->policyDigests.count += 1;
@@ -150,11 +139,103 @@ ifapi_calculate_tree(
         goto_if_error(r, "Compute policy.", cleanup);
 
         break;
-    statecasedefault(context->policy.state);
+    statecasedefault(context->state);
     }
 cleanup:
-    ifapi_free_node_list(context->policy.eval_ctx.policy_elements);
-    context->policy.eval_ctx.policy_elements = NULL;
-    context->policy.state = POLICY_INIT;
+    ifapi_free_node_list(context->eval_ctx.policy_elements);
+    context->eval_ctx.policy_elements = NULL;
+    context->state = POLICY_INIT;
+    return r;
+}
+
+/** Execute a policy tree
+ *
+ * @param state: The policy state.
+ * @param context: The policy execution context.
+ * @param eval_ctx The policy evaluation context.
+ * @param pstore: The policy store, may be NULL and then policy path
+ *      is treated as a regular path.
+ * @param io: The FAPI IO Context used for async IO.
+ * @param policyPath: Relative policy path if pstore is not NULL else an absolute
+ *   or relative path to a policy file.
+ * @param policy: Policy structure.
+ * @param esys_ctx: The ESAPI context used to execute policy commands on.
+ * @param hash_alg: The hash alg for policy computations.
+ * @param do_flush: True to flush the policy session on error, false to not flush.
+ *
+ * @retval TSS2_RC_SUCCESS on success.
+ * @retval TSS2_FAPI_RC_AUTHORIZATION_UNKNOWN If the callback for branch selection is
+ *         not defined. This callback will be needed if or policies have to be
+ *         executed.
+ * @retval TSS2_FAPI_RC_BAD_VALUE If the computed branch index deliverd by the
+ *         callback does not identify a branch or If wrong values are detected during execution.
+ * @retval TSS2_FAPI_RC_MEMORY if not enough memory can be allocated.
+ * @retval TSS2_FAPI_RC_BAD_REFERENCE a invalid null pointer is passed.
+ * @retval TSS2_FAPI_RC_IO_ERROR if an error occurs reading the policy file.
+ * @retval TSS2_FAPI_RC_BAD_TEMPLATE In a invalid policy is loaded during execution.
+ * @retval TSS2_FAPI_RC_GENERAL_FAILURE if an internal error occurred.
+ * @retval TSS2_FAPI_RC_AUTHORIZATION_UNKNOWN if a required authorization callback
+ *         is not set.
+ * @retval TSS2_ESYS_RC_* possible error codes of ESAPI.
+ */
+TSS2_RC
+ifapi_execute_tree_ex(
+    enum IFAPI_STATE_POLICY *state,
+    IFAPI_POLICY_EXEC_CTX *context,
+    IFAPI_POLICY_EVAL_INST_CTX *eval_ctx,
+    IFAPI_POLICY_STORE *pstore,
+    IFAPI_IO *io,
+    const char *policyPath,
+    TPMS_POLICY *policy,
+    ESYS_CONTEXT *esys_ctx,
+    TPMI_ALG_HASH hash_alg,
+    bool do_flush)
+{
+    TSS2_RC r = TSS2_RC_SUCCESS;
+
+    if (*state == POLICY_INIT && !policyPath) {
+        /* Skip policy reading */
+        *state = POLICY_EXECUTE_PREPARE;
+    }
+
+    switch (*state) {
+    statecase(*state, POLICY_INIT);
+        fallthrough;
+
+    statecase(*state, POLICY_READ);
+        r = ifapi_policy_store_load_async(pstore, io, policyPath);
+        goto_if_error2(r, "Can't open: %s", cleanup, policyPath);
+        fallthrough;
+
+    statecase(*state, POLICY_READ_FINISH);
+        r = ifapi_policy_store_load_finish(pstore, io, policy);
+        return_try_again(r);
+        goto_if_error(r, "read_finish failed", cleanup);
+        fallthrough;
+
+     statecase(*state, POLICY_EXECUTE_PREPARE);
+        /* No mention of return try again in doc string */
+        r = ifapi_policyeval_execute_prepare(
+            context,
+            hash_alg,
+            policy);
+        goto_if_error(r, "execute policy prepare.", cleanup);
+        fallthrough;
+    statecase(*state, POLICY_EXECUTE);
+        r = ifapi_policyeval_execute(
+            esys_ctx,
+            context,
+            do_flush);
+        return_try_again(r);
+        goto_if_error(r, "execute policy.", cleanup);
+
+        break;
+    statecasedefault(*state);
+    }
+
+cleanup:
+    ifapi_free_node_list(eval_ctx->policy_elements);
+    eval_ctx->policy_elements = NULL;
+    *state = POLICY_INIT;
     return r;
 }
