@@ -874,7 +874,7 @@ cleanup_dl:
 }
 
 /* public info structure */
-const TSS2_TCTI_INFO tss2_tcti_info = {
+const TSS2_TCTI_INFO tss2_tcti_libtpms_info = {
     .version = TCTI_VERSION,
     .name = "tcti-libtpms",
     .description = "TCTI module for communication with the libtpms library.",
@@ -885,5 +885,5 @@ const TSS2_TCTI_INFO tss2_tcti_info = {
 const TSS2_TCTI_INFO *
 Tss2_Tcti_Info(void)
 {
-    return &tss2_tcti_info;
+    return &tss2_tcti_libtpms_info;
 }
