@@ -287,7 +287,7 @@ Tss2_Tcti_Pcap_Init (
 }
 
 /* public info structure */
-const TSS2_TCTI_INFO tss2_tcti_info = {
+const TSS2_TCTI_INFO tss2_tcti_pcap_info = {
     .version = TCTI_VERSION,
     .name = "tcti-pcap",
     .description = "TCTI module for logging TPM commands in pcapng format.",
@@ -298,5 +298,5 @@ const TSS2_TCTI_INFO tss2_tcti_info = {
 const TSS2_TCTI_INFO*
 Tss2_Tcti_Info (void)
 {
-    return &tss2_tcti_info;
+    return &tss2_tcti_pcap_info;
 }
