@@ -228,9 +228,9 @@ tcti_tbs_get_poll_handles (
     size_t *num_handles)
 {
     /* TBS doesn't support polling. */
-    (void)(tctiContext);
-    (void)(handles);
-    (void)(num_handles);
+    UNUSED(tctiContext);
+    UNUSED(handles);
+    UNUSED(num_handles);
     return TSS2_TCTI_RC_NOT_IMPLEMENTED;
 }
 
@@ -242,8 +242,8 @@ tcti_tbs_set_locality (
     /*
      * TBS currently only supports locality 0
      */
-    (void)(tctiContext);
-    (void)(locality);
+    UNUSED(tctiContext);
+    UNUSED(locality);
     return TSS2_TCTI_RC_NOT_IMPLEMENTED;
 }
 
@@ -315,7 +315,7 @@ Tss2_Tcti_Tbs_Init (
     return TSS2_RC_SUCCESS;
 }
 
-const TSS2_TCTI_INFO tss2_tcti_info = {
+const TSS2_TCTI_INFO tss2_tcti_tbs_info = {
     .version = TCTI_VERSION,
     .name = "tcti-tbs",
     .description = "TCTI module for communication with Windows TPM Base Services",
@@ -326,5 +326,5 @@ const TSS2_TCTI_INFO tss2_tcti_info = {
 const TSS2_TCTI_INFO*
 Tss2_Tcti_Info (void)
 {
-    return &tss2_tcti_info;
+    return &tss2_tcti_tbs_info;
 }
