@@ -22,7 +22,7 @@
  * We create a RSA primary signing key which will be used as signing key
  * and as object for the certify command.
  *
- * Tested ESAPI commands:
+ * Tested ESYS commands:
  *  - Esys_Certify() (M)
  *  - Esys_CreatePrimary() (M)
  *  - Esys_FlushContext() (M)
@@ -38,6 +38,13 @@ test_esys_certify(ESYS_CONTEXT * esys_context)
     TSS2_RC r;
     ESYS_TR signHandle = ESYS_TR_NONE;
 
+    TPM2B_PUBLIC *outPublic = NULL;
+    TPM2B_CREATION_DATA *creationData = NULL;
+    TPM2B_DIGEST *creationHash = NULL;
+    TPMT_TK_CREATION *creationTicket = NULL;
+    TPM2B_ATTEST *certifyInfo = NULL;
+    TPMT_SIGNATURE *signature = NULL;
+
     TPM2B_AUTH authValuePrimary = {
         .size = 5,
         .buffer = {1, 2, 3, 4, 5}
@@ -63,7 +70,7 @@ test_esys_certify(ESYS_CONTEXT * esys_context)
             .size = 0,
             .publicArea = {
                 .type = TPM2_ALG_RSA,
-                .nameAlg = TPM2_ALG_SHA1,
+                .nameAlg = TPM2_ALG_SHA256,
                 .objectAttributes = (
                     TPMA_OBJECT_USERWITHAUTH |
                     TPMA_OBJECT_RESTRICTED |
@@ -83,7 +90,7 @@ test_esys_certify(ESYS_CONTEXT * esys_context)
                         },
                     .scheme = {
                          .scheme = TPM2_ALG_RSASSA,
-                         .details = { .rsassa = { .hashAlg = TPM2_ALG_SHA1 }},
+                         .details = { .rsassa = { .hashAlg = TPM2_ALG_SHA256 }},
 
                     },
                     .keyBits = 2048,
@@ -117,11 +124,6 @@ test_esys_certify(ESYS_CONTEXT * esys_context)
     r = Esys_TR_SetAuth(esys_context, ESYS_TR_RH_OWNER, &authValue);
     goto_if_error(r, "Error: TR_SetAuth", error);
 
-    TPM2B_PUBLIC *outPublic;
-    TPM2B_CREATION_DATA *creationData;
-    TPM2B_DIGEST *creationHash;
-    TPMT_TK_CREATION *creationTicket;
-
     r = Esys_CreatePrimary(esys_context, ESYS_TR_RH_OWNER, ESYS_TR_PASSWORD,
                            ESYS_TR_NONE, ESYS_TR_NONE, &inSensitivePrimary,
                            &inPublic, &outsideInfo, &creationPCR,
@@ -131,8 +133,6 @@ test_esys_certify(ESYS_CONTEXT * esys_context)
 
     TPM2B_DATA qualifyingData = {0};
     TPMT_SIG_SCHEME inScheme = { .scheme = TPM2_ALG_NULL };
-    TPM2B_ATTEST *certifyInfo;
-    TPMT_SIGNATURE *signature;
 
     r = Esys_Certify (
         esys_context,
@@ -151,6 +151,12 @@ test_esys_certify(ESYS_CONTEXT * esys_context)
     r = Esys_FlushContext(esys_context,signHandle);
     goto_if_error(r, "Error: FlushContext", error);
 
+    Esys_Free(outPublic);
+    Esys_Free(creationData);
+    Esys_Free(creationHash);
+    Esys_Free(creationTicket);
+    Esys_Free(certifyInfo);
+    Esys_Free(signature);
     return EXIT_SUCCESS;
 
  error:
@@ -160,10 +166,16 @@ test_esys_certify(ESYS_CONTEXT * esys_context)
             LOG_ERROR("Cleanup signHandle failed.");
         }
     }
+    Esys_Free(outPublic);
+    Esys_Free(creationData);
+    Esys_Free(creationHash);
+    Esys_Free(creationTicket);
+    Esys_Free(certifyInfo);
+    Esys_Free(signature);
     return EXIT_FAILURE;
 }
 
 int
-test_invoke_esapi(ESYS_CONTEXT * esys_context) {
+test_invoke_esys(ESYS_CONTEXT * esys_context) {
     return test_esys_certify(esys_context);
 }
