@@ -17,16 +17,16 @@
 #include "util/log.h"
 #include "util/aux_util.h"
 
-/** This test is intended to test EvictControl and ESAPI Serialization.
+/** This test is intended to test EvictControl and ESYS Serialization.
  *
  * We start by creating a primary key (Esys_CreatePrimary). Based on this
  * key a persistent object is created (Esys_EvictControl). The resource of
  * this object will be serialized and deserialized with the corresponding
- * ESAPI functions (Esys_TR_Serialize, Esys_TR_Deserialize).
+ * ESYS functions (Esys_TR_Serialize, Esys_TR_Deserialize).
  * To check whether the deserialization was successful a new object will
  * be created with the handle returned by the deserialize function.
  *
- * Tested ESAPI commands:
+ * Tested ESYS commands:
  *  - Esys_Create() (M)
  *  - Esys_CreatePrimary() (M)
  *  - Esys_EvictControl() (M)
@@ -44,6 +44,16 @@ test_esys_evict_control_serialization(ESYS_CONTEXT * esys_context)
     ESYS_TR primaryHandle = ESYS_TR_NONE;
     ESYS_TR persistent_handle1 = ESYS_TR_NONE;
 
+    TPM2B_PUBLIC *outPublic = NULL;
+    TPM2B_CREATION_DATA *creationData = NULL;
+    TPM2B_DIGEST *creationHash = NULL;
+    TPMT_TK_CREATION *creationTicket = NULL;
+    TPM2B_PUBLIC *outPublic2 = NULL;
+    TPM2B_PRIVATE *outPrivate2 = NULL;
+    TPM2B_CREATION_DATA *creationData2 = NULL;
+    TPM2B_DIGEST *creationHash2 = NULL;
+    TPMT_TK_CREATION *creationTicket2 = NULL;
+
     TPM2B_AUTH authValuePrimary = {
         .size = 5,
         .buffer = {1, 2, 3, 4, 5}
@@ -116,10 +126,6 @@ test_esys_evict_control_serialization(ESYS_CONTEXT * esys_context)
     goto_if_error(r, "Error: TR_SetAuth", error);
 
     RSRC_NODE_T *primaryHandle_node;
-    TPM2B_PUBLIC *outPublic;
-    TPM2B_CREATION_DATA *creationData;
-    TPM2B_DIGEST *creationHash;
-    TPMT_TK_CREATION *creationTicket;
 
     r = Esys_CreatePrimary(esys_context, ESYS_TR_RH_OWNER, ESYS_TR_PASSWORD,
                            ESYS_TR_NONE, ESYS_TR_NONE, &inSensitivePrimary, &inPublic,
@@ -224,12 +230,6 @@ test_esys_evict_control_serialization(ESYS_CONTEXT * esys_context)
         .count = 0,
     };
 
-    TPM2B_PUBLIC *outPublic2;
-    TPM2B_PRIVATE *outPrivate2;
-    TPM2B_CREATION_DATA *creationData2;
-    TPM2B_DIGEST *creationHash2;
-    TPMT_TK_CREATION *creationTicket2;
-
     r = Esys_TR_SetAuth(esys_context, persistent_handle2, &authValuePrimary);
     goto_if_error(r, "Error: TR_SetAuth", error);
 
@@ -254,6 +254,15 @@ test_esys_evict_control_serialization(ESYS_CONTEXT * esys_context)
                           permanentHandle, &persistent_handle1);
     goto_if_error(r, "Error Esys EvictControl", error);
 
+    Esys_Free(outPublic);
+    Esys_Free(creationData);
+    Esys_Free(creationHash);
+    Esys_Free(creationTicket);
+    Esys_Free(outPublic2);
+    Esys_Free(outPrivate2);
+    Esys_Free(creationData2);
+    Esys_Free(creationHash2);
+    Esys_Free(creationTicket2);
     return EXIT_SUCCESS;
 
  error:
@@ -273,10 +282,19 @@ test_esys_evict_control_serialization(ESYS_CONTEXT * esys_context)
         }
     }
 
+    Esys_Free(outPublic);
+    Esys_Free(creationData);
+    Esys_Free(creationHash);
+    Esys_Free(creationTicket);
+    Esys_Free(outPublic2);
+    Esys_Free(outPrivate2);
+    Esys_Free(creationData2);
+    Esys_Free(creationHash2);
+    Esys_Free(creationTicket2);
     return EXIT_FAILURE;
 }
 
 int
-test_invoke_esapi(ESYS_CONTEXT * esys_context) {
+test_invoke_esys(ESYS_CONTEXT * esys_context) {
     return test_esys_evict_control_serialization(esys_context);
 }
