@@ -9,6 +9,7 @@
 #endif
 
 #include <stdlib.h>
+#include <stdio.h>
 
 #include "tss2_esys.h"
 
@@ -45,6 +46,7 @@ test_esys_hmac(ESYS_CONTEXT * esys_context)
     TPM2B_DIGEST *creationHash = NULL;
     TPMT_TK_CREATION *creationTicket = NULL;
     TPM2B_DIGEST *outHMAC = NULL;
+    TPMT_TK_VERIFIED *validation = NULL;
 
     TPM2B_AUTH authValuePrimary = {
         .size = 5,
@@ -107,6 +109,20 @@ test_esys_hmac(ESYS_CONTEXT * esys_context)
         &outHMAC);
     goto_if_error(r, "Error: HMAC", error);
 
+    TPM2B_DIGEST dig = { .size = 20,
+                                     .buffer={0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 0,
+                                              1, 2, 3, 4, 5, 6, 7, 8, 9}} ;
+    TPMT_SIGNATURE sig;
+
+    sig.signature.hmac.hashAlg = TPM2_ALG_SHA256;
+    sig.sigAlg = TPM2_ALG_HMAC;
+    memcpy(sig.signature.hmac.digest.sha256, outHMAC->buffer, outHMAC->size);
+
+    r = Esys_VerifySignature(esys_context, primaryHandle, ESYS_TR_NONE,
+                             ESYS_TR_NONE, ESYS_TR_NONE, &dig, &sig,
+                             &validation);
+    goto_if_error(r, "Error: VerifySignature", error);
+
     r = Esys_FlushContext(esys_context, primaryHandle);
     goto_if_error(r, "Error: FlushContext", error);
 
@@ -115,6 +131,7 @@ test_esys_hmac(ESYS_CONTEXT * esys_context)
     Esys_Free(creationHash);
     Esys_Free(creationTicket);
     Esys_Free(outHMAC);
+    Esys_Free(validation);
     return EXIT_SUCCESS;
 
  error:
@@ -130,6 +147,7 @@ test_esys_hmac(ESYS_CONTEXT * esys_context)
     Esys_Free(creationHash);
     Esys_Free(creationTicket);
     Esys_Free(outHMAC);
+    Esys_Free(validation);
     return EXIT_FAILURE;
 }
 
