@@ -72,6 +72,7 @@ auth_callback(
  * @param[in,out] context The FAPI_CONTEXT.
  * @retval EXIT_FAILURE
  * @retval EXIT_SUCCESS
+ * @retval EXIT_SKIP
  */
 int
 test_fapi_get_esys_blobs(FAPI_CONTEXT *context)
@@ -90,6 +91,11 @@ test_fapi_get_esys_blobs(FAPI_CONTEXT *context)
     ESYS_TR        esys_handle;
     uint8_t        type;
 
+    if (strncmp(FAPI_PROFILE,"P_ECC", 5)) {
+        LOG_WARNING("Profile %s is no ECC profile.", FAPI_PROFILE);
+        return EXIT_SKIP;
+    }
+
     /* We need to reset the passwords again, in order to not brick physical TPMs */
     r = Fapi_Provision(context, NULL, NULL, NULL);
     goto_if_error(r, "Error Fapi_Provision", error);
@@ -178,7 +184,12 @@ test_fapi_get_esys_blobs(FAPI_CONTEXT *context)
         &inScheme,
         &hash_validation,
         &signature);
-    goto_if_error(r, "Error: Sign", error);
+
+    if (r != TSS2_RC_SUCCESS) {
+        LOG_ERROR("%s " TPM2_ERROR_FORMAT, "Error: Sign", TPM2_ERROR_TEXT(r));
+        Esys_FlushContext(context->esys, esys_handle);
+        goto error;
+    }
 
     SAFE_FREE(signature);
 
