@@ -93,7 +93,7 @@ test_fapi_key_create_sign_policy_provision(FAPI_CONTEXT *context)
         "VrpSGMIFSu301A==\n"
         "-----END CERTIFICATE-----\n";
 
-    if (strcmp("P_ECC", fapi_profile) != 0)
+    if (strncmp("P_ECC", fapi_profile, 5) != 0)
         sigscheme = "RSA_PSS";
 
     /* We need to reset the passwords again, in order to not brick physical TPMs */
