@@ -23,6 +23,17 @@
 
 #define EVENT_SIZE 10
 
+static bool big_endian(void) {
+
+    uint32_t test_word;
+    uint8_t *test_byte;
+
+    test_word = 0xFF000000;
+    test_byte = (uint8_t *) (&test_word);
+
+    return test_byte[0] == 0xFF;
+}
+
 /** Test the FAPI functions for quote commands.
  *
  * Tested FAPI commands:
@@ -56,6 +67,10 @@ test_fapi_quote_destructive(FAPI_CONTEXT *context)
     size_t signatureSize = 0;
     uint32_t pcrList[2] = { 11, 16 };
 
+    if (big_endian()) {
+        return EXIT_SKIP;
+    }
+
     r = Fapi_Provision(context, NULL, NULL, NULL);
 
     goto_if_error(r, "Error Fapi_Provision", error);
