@@ -29,7 +29,7 @@ typedef TSS2_TCTI_CONTEXT_COMMON_V1 TSS2_TCTI_CONTEXT_FAKE;
 void
 tcti_fake_finalize(TSS2_TCTI_CONTEXT *tctiContext)
 {
-    (void)(tctiContext);
+    UNUSED(tctiContext);
 }
 
 TSS2_RC
@@ -56,9 +56,10 @@ __wrap_Tss2_TctiLdr_Initialize (const char *nameConf,
 }
 
 void
-tctildr_finalize_data (void **data)
+__wrap_Tss2_TctiLdr_Finalize (TSS2_TCTI_CONTEXT **tcti)
 {
-    return;
+    free(*tcti);
+    *tcti = NULL;
 }
 
 static void
