@@ -25,81 +25,13 @@
 #include "ifapi_json_serialize.h"
 #include "ifapi_json_deserialize.h"
 #include "fapi_policy.h"
+#include "ifapi_helpers.h"
 
 #include "util/aux_util.h"
 
 #define LOGMODULE tests
 #include "util/log.h"
 
-static void
-cleanup_policy_element(TPMT_POLICYELEMENT *policy)
-{
-        switch (policy->type) {
-        case POLICYSECRET:
-            SAFE_FREE(policy->element.PolicySecret.objectPath);
-            break;
-        case POLICYAUTHORIZE:
-            SAFE_FREE(policy->element.PolicyAuthorize.keyPath);
-            SAFE_FREE(policy->element.PolicyAuthorize.keyPEM);
-            break;
-        case POLICYAUTHORIZENV:
-            SAFE_FREE( policy->element.PolicyAuthorizeNv.nvPath);
-            SAFE_FREE( policy->element.PolicyAuthorizeNv.policy_buffer);
-            break;
-        case POLICYSIGNED:
-            SAFE_FREE(policy->element.PolicySigned.keyPath);
-            SAFE_FREE(policy->element.PolicySigned.keyPEM);
-            break;
-        case POLICYPCR:
-            SAFE_FREE(policy->element.PolicyPCR.pcrs);
-            break;
-        case POLICYNV:
-            SAFE_FREE(policy->element.PolicyNV.nvPath);
-            break;
-        case POLICYDUPLICATIONSELECT:
-            SAFE_FREE(policy->element.PolicyDuplicationSelect.newParentPath);
-            break;
-        }
-}
-
-static void cleanup_policy_elements(TPML_POLICYELEMENTS *policy)
-{
-    size_t i, j;
-    if (policy != NULL) {
-        for (i = 0; i < policy->count; i++) {
-            if (policy->elements[i].type ==  POLICYOR) {
-                /* Policy with sub policies */
-                TPML_POLICYBRANCHES *branches = policy->elements[i].element.PolicyOr.branches;
-                for (j = 0; j < branches->count; j++) {
-                    SAFE_FREE(branches->authorizations[j].name);
-                    SAFE_FREE(branches->authorizations[j].description);
-                    cleanup_policy_elements(branches->authorizations[j].policy);
-                }
-                SAFE_FREE(branches);
-            } else {
-                cleanup_policy_element(&policy->elements[i]);
-            }
-        }
-        SAFE_FREE(policy);
-    }
-}
-
-/** Free memory allocated during deserialization of policy.
- *
- * The object will not be freed (might be declared on the stack).
- *
- * @param[in]  object The policy to be cleaned up.
- *
- */
-static void ifapi_cleanup_policy(TPMS_POLICY *policy)
-{
-    if (policy) {
-       SAFE_FREE(policy->description);
-       SAFE_FREE(policy->policyAuthorizations);
-       cleanup_policy_elements(policy->policy);
-    }
-}
-
 /* 6 copies of cleanup functions from ifapi_keystore.c */
 
 void
@@ -241,6 +173,35 @@ char * normalize(const char *string) {
 #define CHECK_JSON(TYPE, SRC, DST)  \
     CHECK_JSON2(TYPE, SRC, DST, &out)
 
+#define CHECK_POLICY2(SRC, DST, PSERIALIZE)                   \
+        { \
+            TPMS_POLICY out; \
+            TSS2_RC rc; \
+            json_object *jso = json_tokener_parse((SRC)); \
+            if (!jso) fprintf(stderr, "JSON parsing failed\n"); \
+            assert_non_null(jso); \
+            rc = ifapi_json_TPMS_POLICY_deserialize (jso, &out); \
+            if (rc) fprintf(stderr, "Deserialization failed\n"); \
+            assert_int_equal (rc, TSS2_RC_SUCCESS); \
+            json_object_put(jso); \
+            jso = NULL; \
+            rc = ifapi_json_TPMS_POLICY_serialize (PSERIALIZE, &jso); \
+            assert_int_equal (rc, TSS2_RC_SUCCESS); \
+            assert_non_null(jso); \
+            const char *jso_string = json_object_to_json_string_ext(jso, JSON_C_TO_STRING_PRETTY); \
+            assert_non_null(jso_string); \
+            char *string1 = normalize(jso_string); \
+            char *string2 =  normalize(DST); \
+            assert_string_equal(string1, string2); \
+            json_object_put(jso); \
+            ifapi_cleanup_policy(&out); \
+            free(string1); \
+            free(string2); \
+        }
+
+#define CHECK_POLICY(SRC, DST)  \
+    CHECK_POLICY2(SRC, DST, &out)
+
 #define CHECK_JSON_SIMPLE(TYPE, SRC, DST)  \
     CHECK_JSON2(TYPE, SRC, DST, out)
 
@@ -493,17 +454,6 @@ check_bin(void **state)
     };
 
     CHECK_BIN(TPML_PCR_SELECTION, pcr_selection);
-
-    IFAPI_IMA_EVENT imaEvent = {
-        .eventData = {
-            .size = 0,
-            .buffer = { 0 }
-        },
-        .eventName = "Event"
-    };
-
-    CHECK_BIN(IFAPI_IMA_EVENT, imaEvent);
-    free(imaEvent2.eventName);
 }
 
 static void
@@ -683,7 +633,7 @@ check_json_structs(void **state)
         "  \"size\":0,\n"
         "  \"publicArea\":{\n"
         "    \"type\":\"ECC\",\n"
-        "    \"nameAlg\":\"SHA1\",\n"
+        "    \"nameAlg\":\"sha1\",\n"
         "\"objectAttributes\":{"
         "      \"fixedTPM\":1,"
         "      \"stClear\":0,"
@@ -705,7 +655,7 @@ check_json_structs(void **state)
         "      \"scheme\":{\n"
         "        \"scheme\":\"ECDAA\",\n"
         "        \"details\":{\n"
-        "          \"hashAlg\":\"SHA256\",\n"
+        "          \"hashAlg\":\"sha256\",\n"
         "          \"count\":0\n"
         "        }\n"
         "      },\n"
@@ -726,7 +676,7 @@ check_json_structs(void **state)
         "  \"size\":0,"
         "  \"publicArea\":{"
         "    \"type\":\"ECC\","
-        "    \"nameAlg\":\"SHA1\","
+        "    \"nameAlg\":\"sha1\","
         "    \"objectAttributes\":["
         "      \"fixedTPM\","
         "      \"fixedParent\","
@@ -743,7 +693,7 @@ check_json_structs(void **state)
         "      \"scheme\":{"
         "        \"scheme\":\"ECDAA\","
         "        \"details\":{"
-        "          \"hashAlg\":\"SHA256\","
+        "          \"hashAlg\":\"sha256\","
         "          \"count\":0"
         "        }"
         "      },"
@@ -951,7 +901,7 @@ check_json_structs(void **state)
         "    \"firmwareVersion\": 783,\n"
         "    \"attested\": {\n"
         "        \"auditCounter\": 456,\n"
-        "        \"digestAlg\": \"SHA1\",\n"
+        "        \"digestAlg\": \"sha1\",\n"
         "        \"auditDigest\": \"00010203040506070809c0c1c2c3c4c5c6c7c8c9\",\n"
         "        \"commandDigest\": \"00010203040506070809d0d1d2d3d4d5d6d7d8d9\"\n"
         "    }\n"
@@ -1056,14 +1006,14 @@ check_json_structs(void **state)
         "{\n"
         "    \"scheme\": \"HMAC\",\n"
         "    \"details\": {\n"
-        "        \"hashAlg\": \"SHA256\"\n"
+        "        \"hashAlg\": \"sha256\"\n"
         "    }\n"
         "}";
     const char *test_json_TPMT_KEYEDHASH_SCHEME_hmac_expt =
         "{\n"
         "    \"scheme\": \"HMAC\",\n"
         "    \"details\": {\n"
-        "        \"hashAlg\": \"SHA256\"\n"
+        "        \"hashAlg\": \"sha256\"\n"
         "    }\n"
         "}";
     CHECK_JSON(TPMT_KEYEDHASH_SCHEME, test_json_TPMT_KEYEDHASH_SCHEME_hmac_src, test_json_TPMT_KEYEDHASH_SCHEME_hmac_expt);
@@ -1072,7 +1022,7 @@ check_json_structs(void **state)
         "{\n"
         "    \"scheme\": \"XOR\",\n"
         "    \"details\": {\n"
-        "        \"hashAlg\": \"SHA256\",\n"
+        "        \"hashAlg\": \"sha256\",\n"
         "        \"kdf\": \"MGF1\"\n"
         "    }\n"
         "}";
@@ -1080,7 +1030,7 @@ check_json_structs(void **state)
         "{\n"
         "    \"scheme\": \"XOR\",\n"
         "    \"details\": {\n"
-        "        \"hashAlg\": \"SHA256\",\n"
+        "        \"hashAlg\": \"sha256\",\n"
         "        \"kdf\": \"MGF1\"\n"
         "    }\n"
         "}";
@@ -1090,7 +1040,7 @@ check_json_structs(void **state)
         "{\n"
         "    \"handle\":0,"
         "    \"policyHash\": {\n"
-        "        \"hashAlg\":\"SHA256\",\n"
+        "        \"hashAlg\":\"sha256\",\n"
         "        \"digest\":\"59215cb6c21a60e26b2cc479334a021113611903795507c1227659e2aef23d16\"\n"
         "    }\n"
         "}";
@@ -1099,7 +1049,7 @@ check_json_structs(void **state)
         "{\n"
         "    \"handle\":0,"
         "    \"policyHash\": {\n"
-        "        \"hashAlg\":\"SHA256\",\n"
+        "        \"hashAlg\":\"sha256\",\n"
         "        \"digest\":\"59215cb6c21a60e26b2cc479334a021113611903795507c1227659e2aef23d16\"\n"
         "    }\n"
         "}";
@@ -1124,14 +1074,120 @@ check_json_structs(void **state)
         "    }"
         "}";
     CHECK_JSON(TPMS_ACT_DATA, test_json_TPMS_ACT_DATA_src, test_json_TPMS_ACT_DATA_expt);
+
+    /*
+     * Check whether policy version with complex TPM2B for newParentPublic in policy
+     * POLICYDUPLICATIONSELECT is deserialized to TPMT_PUBLIC.
+     */
+
+    const char *test_json_TPMS_POLICY_src =
+        "{\n"
+        "    \"description\":\"Description pol_duplicate\",\n"
+        "    \"policy\":[\n"
+        "        {\n"
+        "            \"type\": \"POLICYDUPLICATIONSELECT\",\n"
+        "            \"newParentPublic\":\n"
+        "            {\n"
+        "                \"size\":90,\n"
+        "                \"publicArea\":{\n"
+        "                    \"type\":\"ECC\",\n"
+        "                    \"nameAlg\":\"sha256\",\n"
+        "                    \"objectAttributes\":{\n"
+        "                        \"fixedTPM\":1,\n"
+        "                        \"stClear\":0,\n"
+        "                        \"fixedParent\":1,\n"
+        "                        \"sensitiveDataOrigin\":1,\n"
+        "                        \"userWithAuth\":1,\n"
+        "                        \"adminWithPolicy\":0,\n"
+        "                        \"noDA\":1,\n"
+        "                        \"encryptedDuplication\":0,\n"
+        "                        \"restricted\":1,\n"
+        "                        \"decrypt\":1,\n"
+        "                        \"sign\":0\n"
+        "                    },\n"
+        "                    \"authPolicy\":\"\",\n"
+        "                    \"parameters\":{\n"
+        "                        \"symmetric\":{\n"
+        "                            \"algorithm\":\"AES\",\n"
+        "                            \"keyBits\":128,\n"
+        "                            \"mode\":\"CFB\"\n"
+        "                        },\n"
+        "                        \"scheme\":{\n"
+        "                            \"scheme\":\"NULL\"\n"
+        "                        },\n"
+        "                        \"curveID\":\"NIST_P256\",\n"
+        "                        \"kdf\":{\n"
+        "                            \"scheme\":\"NULL\"\n"
+        "                        }\n"
+        "                    },\n"
+        "                    \"unique\":{\n"
+        "                        \"x\":\"a12497c5ba7473779d02fd7a9df5b7afc7bc6db6d9f5eccb0b74a265259cacce\",\n"
+        "                        \"y\":\"b92b44809e190e721524696e2eab1da8dea0f7bd9cd6c38d5d9804c5c64faa95\"\n"
+        "                    }\n"
+        "                }\n"
+        "            }\n"
+        "        }\n"
+        "    ]\n"
+        "}\n";
+
+       const char *test_json_TPMS_POLICY_expt =
+        "{\n"
+        "    \"description\":\"Description pol_duplicate\",\n"
+        "    \"policyDigests\":[],\n"
+        "    \"policy\":[\n"
+        "        {\n"
+        "            \"type\": \"POLICYDUPLICATIONSELECT\",\n"
+        "            \"objectName\":\"\",\"includeObject\":\"NO\","
+        "            \"newParentPublic\":\n"
+        "            {\n"
+        "                \"type\":\"ECC\",\n"
+        "                \"nameAlg\":\"sha256\",\n"
+        "                \"objectAttributes\":{\n"
+        "                    \"fixedTPM\":1,\n"
+        "                    \"stClear\":0,\n"
+        "                    \"fixedParent\":1,\n"
+        "                    \"sensitiveDataOrigin\":1,\n"
+        "                    \"userWithAuth\":1,\n"
+        "                    \"adminWithPolicy\":0,\n"
+        "                    \"noDA\":1,\n"
+        "                    \"encryptedDuplication\":0,\n"
+        "                    \"restricted\":1,\n"
+        "                    \"decrypt\":1,\n"
+        "                    \"sign\":0\n"
+        "                },\n"
+        "                \"authPolicy\":\"\",\n"
+        "                \"parameters\":{\n"
+        "                    \"symmetric\":{\n"
+        "                        \"algorithm\":\"AES\",\n"
+        "                        \"keyBits\":128,\n"
+        "                        \"mode\":\"CFB\"\n"
+        "                    },\n"
+        "                    \"scheme\":{\n"
+        "                        \"scheme\":\"NULL\"\n"
+        "                    },\n"
+        "                    \"curveID\":\"NIST_P256\",\n"
+        "                    \"kdf\":{\n"
+        "                        \"scheme\":\"NULL\"\n"
+        "                    }\n"
+        "                },\n"
+        "                \"unique\":{\n"
+        "                    \"x\":\"a12497c5ba7473779d02fd7a9df5b7afc7bc6db6d9f5eccb0b74a265259cacce\",\n"
+        "                    \"y\":\"b92b44809e190e721524696e2eab1da8dea0f7bd9cd6c38d5d9804c5c64faa95\"\n"
+        "                }\n"
+        "            }\n"
+        "        }\n"
+        "    ]\n"
+        "}\n";
+
+      CHECK_POLICY(test_json_TPMS_POLICY_src, test_json_TPMS_POLICY_expt);
 }
 
 static void
 check_json_constants(void **state)
 {
-    CHECK_JSON_SIMPLE(TPMI_ALG_HASH, "\"sha1\"", "\"SHA1\"");
-    CHECK_JSON_SIMPLE(TPMI_ALG_HASH, "\"0x04\"", "\"SHA1\"");
-    CHECK_JSON_SIMPLE(TPMI_ALG_HASH, "4", "\"SHA1\"");
+    CHECK_JSON_SIMPLE(TPMI_ALG_HASH, "\"sha1\"", "\"sha1\"");
+    CHECK_JSON_SIMPLE(TPMI_ALG_HASH, "\"0x04\"", "\"sha1\"");
+    CHECK_JSON_SIMPLE(TPMI_ALG_HASH, "4", "\"sha1\"");
 }
 
 static void
@@ -1361,7 +1417,7 @@ check_json_policy(void **state)
         "  \"description\":\"hareness description\","
         "  \"policyDigests\":["
         "    {"
-        "      \"hashAlg\":\"SHA256\","
+        "      \"hashAlg\":\"sha256\","
         "      \"digest\":\"59215cb6c21a60e26b2cc479334a021113611903795507c1227659e2aef23d16\""
         "    }"
         "  ],"
@@ -1370,7 +1426,7 @@ check_json_policy(void **state)
         "      \"type\":\"POLICYOR\","
         "      \"policyDigests\":["
         "        {"
-        "          \"hashAlg\":\"SHA256\","
+        "          \"hashAlg\":\"sha256\","
         "          \"digest\":\"59215cb6c21a60e26b2cc479334a021113611903795507c1227659e2aef23d16\""
         "        }"
         "      ],"
@@ -1383,14 +1439,14 @@ check_json_policy(void **state)
         "                \"type\":\"POLICYPCR\","
         "                \"policyDigests\":["
         "                  {"
-        "                    \"hashAlg\":\"SHA256\","
+        "                    \"hashAlg\":\"sha256\","
         "                    \"digest\":\"17d552f8e39ad882f6b3c09ae139af59616bf6a63f4093d6d20e9e1b9f7cdb6e\""
         "                  }"
         "                ],"
         "                  \"pcrs\":["
         "                    {"
         "                      \"pcr\":16,"
-        "                      \"hashAlg\":\"SHA1\","
+        "                      \"hashAlg\":\"sha1\","
         "                      \"digest\":\"0000000000000000000000000000000000000000\""
         "                    }"
         "                  ]"
@@ -1398,7 +1454,7 @@ check_json_policy(void **state)
         "            ],"
         "            \"policyDigests\":["
         "              {"
-        "                \"hashAlg\":\"SHA256\","
+        "                \"hashAlg\":\"sha256\","
         "                \"digest\":\"17d552f8e39ad882f6b3c09ae139af59616bf6a63f4093d6d20e9e1b9f7cdb6e\""
         "              }"
         "            ]"
@@ -1411,14 +1467,14 @@ check_json_policy(void **state)
         "                \"type\":\"POLICYPCR\","
         "                \"policyDigests\":["
         "                  {"
-        "                    \"hashAlg\":\"SHA256\","
+        "                    \"hashAlg\":\"sha256\","
         "                    \"digest\":\"17d552f8e39ad882f6b3c09ae139af59616bf6a63f4093d6d20e9e1b9f7cdb6e\""
         "                  }"
         "                ],"
         "                  \"pcrs\":["
         "                    {"
         "                      \"pcr\":16,"
-        "                      \"hashAlg\":\"SHA1\","
+        "                      \"hashAlg\":\"sha1\","
         "                      \"digest\":\"0000000000000000000000000000000000000000\""
         "                    }"
         "                  ]"
@@ -1426,7 +1482,7 @@ check_json_policy(void **state)
         "            ],"
         "            \"policyDigests\":["
         "              {"
-        "                \"hashAlg\":\"SHA256\","
+        "                \"hashAlg\":\"sha256\","
         "                \"digest\":\"17d552f8e39ad882f6b3c09ae139af59616bf6a63f4093d6d20e9e1b9f7cdb6e\""
         "              }"
         "            ]"
@@ -1491,7 +1547,7 @@ check_error(void **state)
                 TSS2_FAPI_RC_BAD_VALUE);
 
     /* Illegal values */
-    CHECK_ERROR(TPMI_ALG_HASH, "\"SHA9999\"", TSS2_FAPI_RC_BAD_VALUE);
+    CHECK_ERROR(TPMI_ALG_HASH, "\"sha9999\"", TSS2_FAPI_RC_BAD_VALUE);
     CHECK_ERROR(TPM2B_DIGEST, "\"xxxx\"", TSS2_FAPI_RC_BAD_VALUE);
     CHECK_ERROR(TPM2B_DIGEST, "\"0x010x\"", TSS2_FAPI_RC_BAD_VALUE);
 
@@ -1526,7 +1582,7 @@ check_error(void **state)
         "    \"size\":122,"
         "    \"publicArea\":{"
         "      \"type\":\"ECC\","
-        "      \"nameAlg\":\"SHA256\","
+        "      \"nameAlg\":\"sha256\","
         "      \"objectAttributes\":1,"
         "      \"authPolicy\":\"837197674484b3f81a90cc8d46a5d724fd52d76e06520b64f2a1da1b331469aa\","
         "      \"parameters\":{"
@@ -1563,7 +1619,7 @@ check_error(void **state)
         "    \"size\":122,"
         "    \"publicArea\":{"
         "      \"type\":\"ECC\","
-        "      \"nameAlg\":\"SHA256\","
+        "      \"nameAlg\":\"sha256\","
         "      \"objectAttributes\":{"
         "        \"fixedTPM\":1,"
         "        \"stClear\":0,"
@@ -1613,7 +1669,7 @@ check_error(void **state)
         "    \"size\":122,"
         "    \"publicArea\":{"
         "      \"type\":\"ECC\","
-        "      \"nameAlg\":\"SHA256\","
+        "      \"nameAlg\":\"sha256\","
         "      \"objectAttributes\":{"
         "        \"fixedTPM\":1,"
         "        \"stClear\":0,"
@@ -1665,7 +1721,7 @@ check_error(void **state)
         "    \"size\":122,"
         "    \"publicArea\":{"
         "      \"type\":\"ECC\","
-        "      \"nameAlg\":\"SHA256\","
+        "      \"nameAlg\":\"sha256\","
         "      \"objectAttributes\":{"
         "        \"fixedTPM\":1,"
         "        \"stClear\":0,"
@@ -1715,7 +1771,7 @@ check_error(void **state)
         "    \"size\":122,"
         "    \"publicArea\":{"
         "      \"type\":\"ECC\","
-        "      \"nameAlg\":\"SHA256\","
+        "      \"nameAlg\":\"sha256\","
         "      \"objectAttributes\":{"
         "        \"fixedTPM\":1,"
         "        \"stClear\":0,"
@@ -1768,7 +1824,7 @@ check_error(void **state)
         "    \"size\":122,"
         "    \"publicArea\":{"
         "      \"type\":\"ECC\","
-        "      \"nameAlg\":\"SHA256\","
+        "      \"nameAlg\":\"sha256\","
         "      \"objectAttributes\":{"
         "        \"fixedTPM\":1,"
         "        \"stClear\":0,"
@@ -1812,7 +1868,7 @@ check_error(void **state)
           "  \"signing_scheme\":{"
           "    \"scheme\":\"ECDSA\","
           "    \"details\":{"
-          "      \"hashAlg\":\"SHA256\""
+          "      \"hashAlg\":\"sha256\""
           "    }"
           "  },"
          "}";
@@ -1842,7 +1898,7 @@ check_error(void **state)
         "    \"size\":0,"
         "    \"nvPublic\":{"
         "      \"nvIndex\":25165824,"
-        "      \"nameAlg\":\"SHA256\","
+        "      \"nameAlg\":\"sha256\","
         "      \"attributes\":{"
         "        \"PPWRITE\":0,"
         "        \"OWNERWRITE\":0,"
@@ -1888,7 +1944,7 @@ check_error(void **state)
         "    \"size\":0,"
         "    \"nvPublic\":{"
         "      \"nvIndex\":25165824,"
-        "      \"nameAlg\":\"SHA256\","
+        "      \"nameAlg\":\"sha256\","
         "      \"attributes\":{"
         "        \"PPWRITE\":0,"
         "        \"OWNERWRITE\":0,"
@@ -1931,7 +1987,7 @@ check_error(void **state)
         "    \"size\":0,"
         "    \"nvPublic\":{"
         "      \"nvIndex\":25165824,"
-        "      \"nameAlg\":\"SHA256\","
+        "      \"nameAlg\":\"sha256\","
         "      \"attributes\":{"
         "        \"PPWRITE\":0,"
         "        \"OWNERWRITE\":0,"
@@ -1976,7 +2032,7 @@ check_error(void **state)
         "    \"size\":0,"
         "    \"nvPublic\":{"
         "      \"nvIndex\":25165824,"
-        "      \"nameAlg\":\"SHA256\","
+        "      \"nameAlg\":\"sha256\","
         "      \"attributes\":{"
         "        \"PPWRITE\":0,"
         "        \"OWNERWRITE\":0,"
@@ -2248,9 +2304,9 @@ static void
 check_tpmjson_tofromtxt(void **state)
 {
     const char *testcase_alg_id[] = { "\"TPM_ALG_ID_SHA1\"", "\"TPM2_ALG_ID_SHA1\"",
-                                      "\"ALG_ID_SHA1\"", "\"SHA1\"", "\"ALG_SHA1\"",
+                                      "\"ALG_ID_SHA1\"", "\"sha1\"", "\"ALG_SHA1\"",
                                       "\"tpm2_alg_id_sha1\"", "\"sha1\"", "\"0x0004\"" };
-    const char *expected_ald_id = { "\"SHA1\"" };
+    const char *expected_ald_id = { "\"sha1\"" };
     for (size_t i = 0; i < sizeof(testcase_alg_id) / sizeof(testcase_alg_id[0]); i++) {
         CHECK_JSON_SIMPLE(TPM2_ALG_ID, testcase_alg_id[i], expected_ald_id);
     }
