@@ -28,6 +28,8 @@
 #define LOGMODULE test
 #include "util/log.h"
 
+#define EXIT_SKIP 77
+
 #define LIBTPMS_DL_HANDLE  0x12345678
 #define STATEFILE_PATH     "statefile.bin"
 #define STATEFILE_FD       0xAABB
@@ -122,11 +124,6 @@ TPM_RESULT TPMLIB_MainInit(void)
     assert_int_equal(ret, 0);
     ret = global_callbacks.tpm_io_init();
     assert_int_equal(ret, 0);
-    ret = global_callbacks.tpm_nvram_loaddata((unsigned char **) 1,
-                                               (uint32_t *) 2,
-                                               3,
-                                               "4");
-    assert_int_equal(ret, TPM_RETRY);
     return mock_type(int);
 }
 TPM_RESULT TPMLIB_Process(unsigned char **resp_buf, uint32_t *resp_len, uint32_t *resp_buf_len, unsigned char *cmd, uint32_t cmd_len)
@@ -139,9 +136,6 @@ TPM_RESULT TPMLIB_Process(unsigned char **resp_buf, uint32_t *resp_len, uint32_t
     assert_int_equal(ret, 0);
     check_expected(locality);
 
-    ret = global_callbacks.tpm_nvram_storedata((unsigned char *) 1, 2, 3, "4");
-    assert_int_equal(ret, TPM_SUCCESS);
-
     unsigned char *buf_out = mock_type(unsigned char *);
     *resp_buf_len = *resp_len = mock_type(uint32_t);
     *resp_buf = malloc(*resp_len);
@@ -159,6 +153,10 @@ TPM_RESULT TPMLIB_SetState(enum TPMLIB_StateType st, const unsigned char *buf, u
 void TPMLIB_Terminate(void)
 {
 }
+TPM_RESULT TPM_IO_TpmEstablished_Reset(void)
+{
+    return TPM_SUCCESS;
+}
 
 void *__wrap_dlopen(const char *filename, int flags)
 {
@@ -387,6 +385,11 @@ tcti_libtpms_init_state_open_fail_test(void **state)
     TSS2_RC ret = TSS2_RC_SUCCESS;
     TSS2_TCTI_CONTEXT *ctx = NULL;
 
+#ifdef __FreeBSD__
+    // Currently, state files are not supported on FreeBSD
+    skip();
+#endif
+
     ret = Tss2_Tcti_Libtpms_Init(NULL, &tcti_size, NULL);
     assert_true(ret == TSS2_RC_SUCCESS);
     ctx = calloc(1, tcti_size);
@@ -424,6 +427,10 @@ tcti_libtpms_init_state_open_fail_test(void **state)
     expect_string(__wrap_dlsym, symbol, "TPMLIB_Terminate");
     will_return(__wrap_dlsym, &TPMLIB_Terminate);
 
+    expect_value(__wrap_dlsym, handle, LIBTPMS_DL_HANDLE);
+    expect_string(__wrap_dlsym, symbol, "TPM_IO_TpmEstablished_Reset");
+    will_return(__wrap_dlsym, &TPM_IO_TpmEstablished_Reset);
+
     /* fail open */
     expect_string(__wrap_open, pathname, STATEFILE_PATH);
     expect_value(__wrap_open, flags, O_RDWR | O_CREAT);
@@ -448,6 +455,11 @@ tcti_libtpms_init_state_lseek_fail_test(void **state)
     TSS2_RC ret = TSS2_RC_SUCCESS;
     TSS2_TCTI_CONTEXT *ctx = NULL;
 
+#ifdef __FreeBSD__
+    // Currently, state files are not supported on FreeBSD
+    skip();
+#endif
+
     ret = Tss2_Tcti_Libtpms_Init(NULL, &tcti_size, NULL);
     assert_true(ret == TSS2_RC_SUCCESS);
     ctx = calloc(1, tcti_size);
@@ -485,6 +497,10 @@ tcti_libtpms_init_state_lseek_fail_test(void **state)
     expect_string(__wrap_dlsym, symbol, "TPMLIB_Terminate");
     will_return(__wrap_dlsym, &TPMLIB_Terminate);
 
+    expect_value(__wrap_dlsym, handle, LIBTPMS_DL_HANDLE);
+    expect_string(__wrap_dlsym, symbol, "TPM_IO_TpmEstablished_Reset");
+    will_return(__wrap_dlsym, &TPM_IO_TpmEstablished_Reset);
+
     expect_string(__wrap_open, pathname, STATEFILE_PATH);
     expect_value(__wrap_open, flags, O_RDWR | O_CREAT);
     expect_value(__wrap_open, mode, 0644);
@@ -519,6 +535,11 @@ tcti_libtpms_init_state_posix_fallocate_fail_test(void **state)
     TSS2_RC ret = TSS2_RC_SUCCESS;
     TSS2_TCTI_CONTEXT *ctx = NULL;
 
+#ifdef __FreeBSD__
+    // Currently, state files are not supported on FreeBSD
+    skip();
+#endif
+
     ret = Tss2_Tcti_Libtpms_Init(NULL, &tcti_size, NULL);
     assert_true(ret == TSS2_RC_SUCCESS);
     ctx = calloc(1, tcti_size);
@@ -556,6 +577,10 @@ tcti_libtpms_init_state_posix_fallocate_fail_test(void **state)
     expect_string(__wrap_dlsym, symbol, "TPMLIB_Terminate");
     will_return(__wrap_dlsym, &TPMLIB_Terminate);
 
+    expect_value(__wrap_dlsym, handle, LIBTPMS_DL_HANDLE);
+    expect_string(__wrap_dlsym, symbol, "TPM_IO_TpmEstablished_Reset");
+    will_return(__wrap_dlsym, &TPM_IO_TpmEstablished_Reset);
+
     expect_string(__wrap_open, pathname, STATEFILE_PATH);
     expect_value(__wrap_open, flags, O_RDWR | O_CREAT);
     expect_value(__wrap_open, mode, 0644);
@@ -596,6 +621,11 @@ tcti_libtpms_init_state_mmap_fail_test(void **state)
     TSS2_RC ret = TSS2_RC_SUCCESS;
     TSS2_TCTI_CONTEXT *ctx = NULL;
 
+#ifdef __FreeBSD__
+    // Currently, state files are not supported on FreeBSD
+    skip();
+#endif
+
     ret = Tss2_Tcti_Libtpms_Init(NULL, &tcti_size, NULL);
     assert_true(ret == TSS2_RC_SUCCESS);
     ctx = calloc(1, tcti_size);
@@ -633,6 +663,10 @@ tcti_libtpms_init_state_mmap_fail_test(void **state)
     expect_string(__wrap_dlsym, symbol, "TPMLIB_Terminate");
     will_return(__wrap_dlsym, &TPMLIB_Terminate);
 
+    expect_value(__wrap_dlsym, handle, LIBTPMS_DL_HANDLE);
+    expect_string(__wrap_dlsym, symbol, "TPM_IO_TpmEstablished_Reset");
+    will_return(__wrap_dlsym, &TPM_IO_TpmEstablished_Reset);
+
     expect_string(__wrap_open, pathname, STATEFILE_PATH);
     expect_value(__wrap_open, flags, O_RDWR | O_CREAT);
     expect_value(__wrap_open, mode, 0644);
@@ -674,6 +708,67 @@ tcti_libtpms_init_state_mmap_fail_test(void **state)
     free(ctx);
 }
 
+/* Currently, state files are not supported on FreeBSD. */
+static void
+tcti_libtpms_init_state_freebsd_fail_test(void **state)
+{
+    size_t tcti_size = 0;
+    TSS2_RC ret = TSS2_RC_SUCCESS;
+    TSS2_TCTI_CONTEXT *ctx = NULL;
+
+    // FreeBSD-only test
+#ifndef __FreeBSD__
+    skip();
+#endif
+
+    ret = Tss2_Tcti_Libtpms_Init(NULL, &tcti_size, NULL);
+    assert_true(ret == TSS2_RC_SUCCESS);
+    ctx = calloc(1, tcti_size);
+    assert_non_null(ctx);
+
+    // successfull dlopen
+    expect_string(__wrap_dlopen, filename, "libtpms.so");
+    expect_value(__wrap_dlopen, flags, RTLD_LAZY | RTLD_LOCAL);
+    will_return(__wrap_dlopen, LIBTPMS_DL_HANDLE);
+
+    expect_value(__wrap_dlsym, handle, LIBTPMS_DL_HANDLE);
+    expect_string(__wrap_dlsym, symbol, "TPMLIB_ChooseTPMVersion");
+    will_return(__wrap_dlsym, &TPMLIB_ChooseTPMVersion);
+
+    expect_value(__wrap_dlsym, handle, LIBTPMS_DL_HANDLE);
+    expect_string(__wrap_dlsym, symbol, "TPMLIB_RegisterCallbacks");
+    will_return(__wrap_dlsym, &TPMLIB_RegisterCallbacks);
+
+    expect_value(__wrap_dlsym, handle, LIBTPMS_DL_HANDLE);
+    expect_string(__wrap_dlsym, symbol, "TPMLIB_GetState");
+    will_return(__wrap_dlsym, &TPMLIB_GetState);
+
+    expect_value(__wrap_dlsym, handle, LIBTPMS_DL_HANDLE);
+    expect_string(__wrap_dlsym, symbol, "TPMLIB_MainInit");
+    will_return(__wrap_dlsym, &TPMLIB_MainInit);
+
+    expect_value(__wrap_dlsym, handle, LIBTPMS_DL_HANDLE);
+    expect_string(__wrap_dlsym, symbol, "TPMLIB_Process");
+    will_return(__wrap_dlsym, &TPMLIB_Process);
+
+    expect_value(__wrap_dlsym, handle, LIBTPMS_DL_HANDLE);
+    expect_string(__wrap_dlsym, symbol, "TPMLIB_SetState");
+    will_return(__wrap_dlsym, &TPMLIB_SetState);
+
+    expect_value(__wrap_dlsym, handle, LIBTPMS_DL_HANDLE);
+    expect_string(__wrap_dlsym, symbol, "TPMLIB_Terminate");
+    will_return(__wrap_dlsym, &TPMLIB_Terminate);
+
+    expect_value(__wrap_dlsym, handle, LIBTPMS_DL_HANDLE);
+    expect_string(__wrap_dlsym, symbol, "TPM_IO_TpmEstablished_Reset");
+    will_return(__wrap_dlsym, &TPM_IO_TpmEstablished_Reset);
+
+    ret = Tss2_Tcti_Libtpms_Init(ctx, &tcti_size, STATEFILE_PATH);
+    assert_int_equal(ret, TSS2_TCTI_RC_BAD_VALUE);
+
+    free(ctx);
+}
+
 /*
  * This is a utility function used by other tests to setup a TCTI context. It
  * effectively wraps the init / allocate / init pattern as well as priming the
@@ -729,6 +824,10 @@ tcti_libtpms_init_from_conf(const char *conf)
     expect_string(__wrap_dlsym, symbol, "TPMLIB_Terminate");
     will_return(__wrap_dlsym, &TPMLIB_Terminate);
 
+    expect_value(__wrap_dlsym, handle, LIBTPMS_DL_HANDLE);
+    expect_string(__wrap_dlsym, symbol, "TPM_IO_TpmEstablished_Reset");
+    will_return(__wrap_dlsym, &TPM_IO_TpmEstablished_Reset);
+
     if (conf != NULL) {
         expect_string(__wrap_open, pathname, STATEFILE_PATH);
         expect_value(__wrap_open, flags, O_RDWR | O_CREAT);
@@ -852,6 +951,10 @@ tcti_libtpms_init_from_conf_real(const char *conf)
     expect_string(__wrap_dlsym, symbol, "TPMLIB_Terminate");
     will_return(__wrap_dlsym, &TPMLIB_Terminate);
 
+    expect_value(__wrap_dlsym, handle, LIBTPMS_DL_HANDLE);
+    expect_string(__wrap_dlsym, symbol, "TPM_IO_TpmEstablished_Reset");
+    will_return(__wrap_dlsym, &TPM_IO_TpmEstablished_Reset);
+
     if (conf != NULL) {
         expect_string(__wrap_open, pathname, conf);
         expect_value(__wrap_open, flags, O_RDWR | O_CREAT);
@@ -896,6 +999,11 @@ tcti_libtpms_locality_success_test(void **state)
     unsigned char cmd[] = {0x80, 0x01, 0x00, 0x00, 0x00, 0x0c, 0x00, 0x00, 0x01, 0x44, 0x00, 0x00};
     unsigned char rsp[] = {0x80, 0x01, 0x00, 0x00, 0x00, 0x0a, 0x00, 0x00, 0x00, 0x00};
 
+#ifdef __FreeBSD__
+    // Currently, state files are not supported on FreeBSD
+    skip();
+#endif
+
     rc = Tss2_Tcti_SetLocality(ctx, 4);
     assert_int_equal(rc, TSS2_RC_SUCCESS);
 
@@ -919,6 +1027,11 @@ tcti_libtpms_transmit_success_test(void **state)
     unsigned char cmd[] = {0x80, 0x01, 0x00, 0x00, 0x00, 0x0c, 0x00, 0x00, 0x01, 0x44, 0x00, 0x00};
     unsigned char rsp[] = {0x80, 0x01, 0x00, 0x00, 0x00, 0x0a, 0x00, 0x00, 0x00, 0x00};
 
+#ifdef __FreeBSD__
+    // Currently, state files are not supported on FreeBSD
+    skip();
+#endif
+
     expect_memory(TPMLIB_Process, cmd, cmd, sizeof(cmd));
     expect_value(TPMLIB_Process, cmd_len, sizeof(cmd));
     expect_value(TPMLIB_Process, locality, 0);
@@ -960,6 +1073,11 @@ tcti_libtpms_receive_success_test(void **state)
     unsigned char rsp_out[sizeof(rsp)];
     size_t rsp_len_out = 0;
 
+#ifdef __FreeBSD__
+    // Currently, state files are not supported on FreeBSD
+    skip();
+#endif
+
     tcti_common->state = TCTI_STATE_RECEIVE;
     tcti_libtpms->response_buffer = malloc(sizeof(rsp));
     assert_non_null(tcti_libtpms->response_buffer);
@@ -994,6 +1112,11 @@ tcti_libtpms_remap_state_success_test(void **state)
     unsigned char cmd[] = {0x80, 0x01, 0x00, 0x00, 0x00, 0x0c, 0x00, 0x00, 0x01, 0x44, 0x00, 0x00};
     unsigned char rsp[] = {0x80, 0x01, 0x00, 0x00, 0x00, 0x0a, 0x00, 0x00, 0x00, 0x00};
 
+#ifdef __FreeBSD__
+    // Currently, state files are not supported on FreeBSD
+    skip();
+#endif
+
     expect_memory(TPMLIB_Process, cmd, cmd, sizeof(cmd));
     expect_value(TPMLIB_Process, cmd_len, sizeof(cmd));
     expect_value(TPMLIB_Process, locality, 0);
@@ -1051,6 +1174,11 @@ tcti_libtpms_remap_state_mremap_fail_test(void **state)
     unsigned char cmd[] = {0x80, 0x01, 0x00, 0x00, 0x00, 0x0c, 0x00, 0x00, 0x01, 0x44, 0x00, 0x00};
     unsigned char rsp[] = {0x80, 0x01, 0x00, 0x00, 0x00, 0x0a, 0x00, 0x00, 0x00, 0x00};
 
+#ifdef __FreeBSD__
+    // Currently, state files are not supported on FreeBSD
+    skip();
+#endif
+
     expect_memory(TPMLIB_Process, cmd, cmd, sizeof(cmd));
     expect_value(TPMLIB_Process, cmd_len, sizeof(cmd));
     expect_value(TPMLIB_Process, locality, 0);
@@ -1094,6 +1222,11 @@ tcti_libtpms_remap_state_posix_fallocate_fail_test(void **state)
     unsigned char cmd[] = {0x80, 0x01, 0x00, 0x00, 0x00, 0x0c, 0x00, 0x00, 0x01, 0x44, 0x00, 0x00};
     unsigned char rsp[] = {0x80, 0x01, 0x00, 0x00, 0x00, 0x0a, 0x00, 0x00, 0x00, 0x00};
 
+#ifdef __FreeBSD__
+    // Currently, state files are not supported on FreeBSD
+    skip();
+#endif
+
     expect_memory(TPMLIB_Process, cmd, cmd, sizeof(cmd));
     expect_value(TPMLIB_Process, cmd_len, sizeof(cmd));
     expect_value(TPMLIB_Process, locality, 0);
@@ -1304,6 +1437,12 @@ tcti_libtpms_two_states_success_test(void **state)
     unsigned char rsp_bb_out[sizeof(rsp_bb)];
     size_t rsp_bb_len_out = sizeof(rsp_bb);
 
+#ifdef __FreeBSD__
+    // Currently, state files are not supported on FreeBSD
+    *state = NULL;
+    skip();
+#endif
+
     tcti_common[0] = tcti_common_context_cast(ctxs[0]);
     tcti_common[1] = tcti_common_context_cast(ctxs[1]);
 
@@ -1402,6 +1541,11 @@ tcti_libtpms_two_states_success_test(void **state)
 static int
 tcti_libtpms_setup(void **state)
 {
+#ifdef __FreeBSD__
+    // Currently, state files are not supported on FreeBSD
+    return 0;
+#endif
+
     fprintf(stderr, "%s: before tcti_libtpms_init_from_conf\n", __func__);
     *state = tcti_libtpms_init_from_conf(STATEFILE_PATH);
     fprintf(stderr, "%s: done\n", __func__);
@@ -1440,7 +1584,14 @@ static int
 tcti_libtpms_setup_two_states(void **state)
 {
     int ret;
-    TSS2_TCTI_CONTEXT **ctxs = malloc(sizeof(void *) * 2);
+    TSS2_TCTI_CONTEXT **ctxs;
+
+#ifdef __FreeBSD__
+    // Currently, state files are not supported on FreeBSD
+    return 0;
+#endif
+
+    ctxs = malloc(sizeof(void *) * 2);
     assert_non_null(ctxs);
 
     /* delete state files if they exist already */
@@ -1491,6 +1642,11 @@ tcti_libtpms_teardown_s1(void **state)
     TSS2_TCTI_CONTEXT *ctx = (TSS2_TCTI_CONTEXT*) *state;
     TSS2_TCTI_LIBTPMS_CONTEXT *tcti_libtpms = (TSS2_TCTI_LIBTPMS_CONTEXT*) ctx;
 
+#ifdef __FreeBSD__
+    // Currently, state files are not supported on FreeBSD
+    return 0;
+#endif
+
     expect_value(__wrap_dlclose, handle, LIBTPMS_DL_HANDLE);
     will_return(__wrap_dlclose, 0);
 
@@ -1519,6 +1675,11 @@ tcti_libtpms_teardown_s2(void **state)
 {
     TSS2_TCTI_CONTEXT *ctx = (TSS2_TCTI_CONTEXT*) *state;
 
+#ifdef __FreeBSD__
+    // Currently, state files are not supported on FreeBSD
+    return 0;
+#endif
+
     expect_value(__wrap_dlclose, handle, LIBTPMS_DL_HANDLE);
     will_return(__wrap_dlclose, 0);
 
@@ -1545,6 +1706,11 @@ tcti_libtpms_teardown_s3(void **state)
 {
     TSS2_TCTI_CONTEXT *ctx = (TSS2_TCTI_CONTEXT*) *state;
 
+#ifdef __FreeBSD__
+    // Currently, state files are not supported on FreeBSD
+    return 0;
+#endif
+
     expect_value(__wrap_dlclose, handle, LIBTPMS_DL_HANDLE);
     will_return(__wrap_dlclose, 0);
 
@@ -1570,8 +1736,18 @@ static int
 tcti_libtpms_teardown_two_states(void **state)
 {
     int ret;
-    TSS2_TCTI_CONTEXT **ctxs = (TSS2_TCTI_CONTEXT**) *state;
-    TSS2_TCTI_LIBTPMS_CONTEXT **tcti_libtpms = (TSS2_TCTI_LIBTPMS_CONTEXT**) ctxs;
+    TSS2_TCTI_CONTEXT **ctxs;
+    TSS2_TCTI_LIBTPMS_CONTEXT **tcti_libtpms;
+
+#ifdef __FreeBSD__
+    // Currently, state files are not supported on FreeBSD
+    if (*state == NULL) {
+        return 0;
+    }
+#endif
+
+    ctxs = (TSS2_TCTI_CONTEXT**) *state;
+    tcti_libtpms = (TSS2_TCTI_LIBTPMS_CONTEXT**) ctxs;
     *state = *ctxs;
 
     /* for both tcti instances */
@@ -1612,6 +1788,12 @@ int
 main(int   argc,
      char *argv[])
 {
+#if _FILE_OFFSET_BITS == 64
+    // Would produce cmocka error
+    LOG_WARNING("_FILE_OFFSET == 64 would produce cmocka errors.");
+    return EXIT_SKIP;
+#endif
+
     const struct CMUnitTest tests[] = {
         cmocka_unit_test(tcti_libtpms_init_all_null_test),
         cmocka_unit_test(tcti_libtpms_init_dlopen_fail_test),
@@ -1620,6 +1802,7 @@ main(int   argc,
         cmocka_unit_test(tcti_libtpms_init_state_lseek_fail_test),
         cmocka_unit_test(tcti_libtpms_init_state_posix_fallocate_fail_test),
         cmocka_unit_test(tcti_libtpms_init_state_mmap_fail_test),
+        cmocka_unit_test(tcti_libtpms_init_state_freebsd_fail_test),
         cmocka_unit_test_setup_teardown(tcti_libtpms_no_statefile_success_test,
                                         tcti_libtpms_setup_no_statefile,
                                         tcti_libtpms_teardown_no_statefile),
