@@ -253,7 +253,9 @@ MAKE_MU_STRUCT(TPML_ALG_PROPERTY);
 MAKE_MU_STRUCT(TPML_ECC_CURVE);
 MAKE_MU_STRUCT(TPML_TAGGED_PCR_PROPERTY);
 MAKE_MU_STRUCT(TPML_TAGGED_TPM_PROPERTY);
+#ifndef DISABLE_VENDOR
 MAKE_MU_STRUCT(TPML_INTEL_PTT_PROPERTY);
+#endif
 MAKE_MU_STRUCT(TPML_AC_CAPABILITIES);
 MAKE_MU_STRUCT(TPML_TAGGED_POLICY);
 MAKE_MU_STRUCT(TPML_ACT_DATA);
